BearDb

Struct BearDb 

pub struct BearDb { /* private fields */ }

Implementations

Source

impl BearDb

pub fn open(path: PathBuf) -> Result<Self>

pub fn find_note( &self, id: Option<&str>, title: Option<&str>, exclude_trashed: bool, ) -> Result<NoteRecord>

pub fn tags(&self) -> Result<Vec<String>>

pub fn notes_for_tags( &self, tags: &[String], include_trashed: bool, ) -> Result<Vec<NoteListItem>>

pub fn search( &self, term: Option<&str>, tag: Option<&str>, include_trashed: bool, since: Option<i64>, before: Option<i64>, ) -> Result<Vec<SearchResult>>

pub fn export_notes(&self, tag: Option<&str>) -> Result<Vec<ExportNote>>

pub fn note_title(&self, note_id: &str) -> Result<Option<String>>

Returns the title of the note with the given identifier, or None if the note does not exist.

pub fn duplicate_titles(&self) -> Result<Vec<DuplicateGroup>>

pub fn stats_summary(&self) -> Result<StatsSummary>

pub fn health_summary(&self) -> Result<HealthSummary>

pub fn untagged(&self, search: Option<&str>) -> Result<Vec<NoteListItem>>

pub fn todo(&self, search: Option<&str>) -> Result<Vec<NoteListItem>>

pub fn today(&self, search: Option<&str>) -> Result<Vec<NoteListItem>>

pub fn locked(&self, search: Option<&str>) -> Result<Vec<NoteListItem>>

pub fn note_files(&self, note_id: &str) -> Result<Vec<NoteFile>>

Returns all file attachments for the note with the given identifier. The file_uuid field can be used to locate the file on disk: Application Data/Local Files/Note Images/{file_uuid}/{filename}